/*
     This file is part of GNUnet.
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * Methods for initializing things in util in
 * the right order.
 * @author Christian Grothoff
 * @file include/util/initialize.h
 **/
#ifndef INITIALIZE_H
#define INITIALIZE_H

/**
 * Method to parse the command line. The results
 * are to be stored in the configuration module.
 * @param argc the number of arguments
 * @param argv the command line arguments
 * @return OK on success, SYSERR if we should abort the
 *   initialization sequence and exit the program
 **/
typedef int (*CommandLineParser)(int argc, char * argv[]);

/**
 * Initialize the util module. 
 * @param argc the number of arguments
 * @param argv the command line arguments
 * @param parser parser to call at the right moment
 * @return OK on success, SYSERR if we should abort
 **/
int initUtil(int argc,
	     char * argv[],
	     CommandLineParser parser);


/**
 * The configuration was re-loaded. All
 * util modules should check if it has
 * changed for them.
 **/
void resetUtil();

/**
 * Shutdown the util services in proper order.
 **/
void doneUtil();

#endif
