/*
     This file is part of GNUnet.
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @author Christian Grothoff
 * @file util/initialize.c
 *
 * Methods for initializing things in util/ in the right order.
 **/

#include "config.h"

#include "util/configuration.h"
#include "util/hostkey.h"
#include "util/identity.h"
#include "util/initialize.h"
#include "util/logging.h"
#include "util/returnvalues.h"
#include "util/statuscalls.h"
#include "util/statistics.h"

/**
 * Initialize the util library. Use argc, argv and the given parser
 * for processing command-line options <bf>after</bf> the
 * configuration module was initialized, but <bf>before</bf> logging
 * and other configuration-dependent features are started.
 **/
int initUtil(int argc,
	     char * argv[],
	     CommandLineParser parser) {
  initRAND();
  initConfiguration();
  initStatistics();
  initCron();
  initTCPIO();  
  if (SYSERR == parser(argc, argv))
    return SYSERR;
  readConfiguration();
  initLogging();
  initStatusCalls();
  initAddress();
  return OK;
}

/**
 * The configuration was re-loaded. All
 * util modules should check if it has
 * changed for them.
 **/
void resetUtil() {
  resetLogging();
  resetStatusCalls();
}

void doneUtil() {
  doneTCPIO();
  doneStatusCalls();
  doneAddress();
  doneCron();
  doneConfiguration();
  doneStatistics();
  LOG(LOG_MESSAGE,
      "Shutdown complete.\n");
  doneLogging();  
}

/* end of initialize.c */
